]> git.ipfire.org Git - ipfire-2.x.git/commitdiff
kernel: change selection of config to support more architectures.
authorArne Fitzenreiter <arne_f@ipfire.org>
Wed, 5 Oct 2011 18:20:36 +0000 (20:20 +0200)
committerArne Fitzenreiter <arne_f@ipfire.org>
Wed, 5 Oct 2011 18:20:36 +0000 (20:20 +0200)
18 files changed:
lfs/Config
lfs/alsa
lfs/compat-wireless
lfs/cryptodev
lfs/dahdi
lfs/e1000
lfs/e1000e
lfs/igb
lfs/kqemu
lfs/kvm-kmod
lfs/linux
lfs/mISDN
lfs/madwifi
lfs/r8101
lfs/r8168
lfs/r8169
lfs/v4l-dvb
make.sh

index b91f2ee63d06705c06d2c1fe13e4a243f93f007a..2bc07547340197df985c595905db7897a1ae192c 100644 (file)
@@ -82,16 +82,8 @@ define PREBUILD
        # Fix installation on partial rebuild, so modules install where they should
        # and not everytime on the last compiled kernel
        if [ -f $(DIR_SRC)/linux-$(KVER) ]; then \
-               if [ "$(PAE)" = "1" ]; then \
-                       cd $(DIR_SRC)/linux-$(KVER) && \
-                               sed -i -e 's+^EXTRAVERSION.*$$+EXTRAVERSION\ =\ $(word 4,$(subst ., .,$(KVER)))-ipfire-pae+' Makefile; \
-               elif [ "$(XEN)" = "" ]; then \
-                       cd $(DIR_SRC)/linux-$(KVER) && \
-                               sed -i -e 's+^EXTRAVERSION.*$$+EXTRAVERSION\ =\ $(word 4,$(subst ., .,$(KVER)))-ipfire+' Makefile; \
-               else \
-                       cd $(DIR_SRC)/linux-$(KVER) && \
-                               sed -i -e 's+^EXTRAVERSION.*$$+EXTRAVERSION\ =\ $(word 4,$(subst ., .,$(KVER)))-ipfire-xen+' Makefile; \
-               fi; \
+               cd $(DIR_SRC)/linux-$(KVER) && \
+                       sed -i -e 's+^EXTRAVERSION.*$$+EXTRAVERSION\ =\ $(word 4,$(subst ., .,$(KVER)))-ipfire$(KCFG)+' Makefile; \
        fi
 endef
 else
@@ -119,10 +111,7 @@ define POSTBUILD
        # $(TARGET)_rootfile : ROOTFILE with KVER replacement
        # $(TARGET) : log result with {commented|include|added} files
        if [ -s "$(TARGET)_diff" ]; then \
-               if [ "$(PAE)" = "1" ]; then LFS_SCRIPT=$(firstword $(MAKEFILE_LIST))-pae; \
-               elif [ "$(XEN)" = "1" ]; then LFS_SCRIPT=$(firstword $(MAKEFILE_LIST))-xen; \
-               else LFS_SCRIPT=$(firstword $(MAKEFILE_LIST)); \
-               fi; \
+               LFS_SCRIPT=$(firstword $(MAKEFILE_LIST))$(KCFG); \
                echo $(LFS_SCRIPT); \
                ROOTFILE=$$(find $(DIR_SRC)/config/rootfiles/{common,packages}/{$(MACHINE),} -maxdepth 1 -type f -name $$LFS_SCRIPT 2>/dev/null | head -1); \
                if [ "$$ROOTFILE" = "" ]; then \
index f6f6df8046fe6eaf08b931d6c90342aee0798884..dadaa145e7ee0c4fffb8ad621fa48a24123b7186 100644 (file)
--- a/lfs/alsa
+++ b/lfs/alsa
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX=ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX=ipfire-xen
-else
-       VERSUFIX=ipfire
-endif
-endif
 
 VER        = 1.0.24.1
 UVER       = 1.0.24.2
 FVER       = 1.0.24.1
 DVER       = 1.0.24
 
+VERSUFIX   = ipfire$(KCFG)
+
 THISAPP    = alsa-lib-$(VER)
 DL_FILE    = $(THISAPP).tar.bz2
 DL_FROM    = $(URL_IPFIRE)
index 4e97dabf8402624d9e45f1170f0c601af5299867..bcde045090a4b39216123faf4675820527943083 100644 (file)
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX=ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX=ipfire-xen
-else
-       VERSUFIX=ipfire
-endif
-endif
+VERSUFIX=ipfire$(KCFG)
 
 VER        = 3.0-2
 
index cd690345609a3eda27925dccbfb52f33b5180200..17a10c7605333f83fe01c0aa0129b00f4d0c7daa 100644 (file)
@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # IPFire.org - A linux based firewall                                         #
-# Copyright (C) 2010  IPFire Team <info@ipfire.org>                           #
+# Copyright (C) 2007-2011  IPFire Team <info@ipfire.org>                      #
 #                                                                             #
 # This program is free software: you can redistribute it and/or modify        #
 # it under the terms of the GNU General Public License as published by        #
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX=ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX=ipfire-xen
-else
-       VERSUFIX=ipfire
-endif
-endif
+VERSUFIX=ipfire$(KCFG)
 
 VER        = 20091126
 
index 8e0de9bdcbdced416dd288a68d73dbae60a0ae15..0ae424c428fdc0e27ba7c80f4ec761e238813e84 100644 (file)
--- a/lfs/dahdi
+++ b/lfs/dahdi
@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # IPFire.org - A linux based firewall                                         #
-# Copyright (C) 2011  IPFire Team <info@ipfire.org>                           #
+# Copyright (C) 2007-2011  IPFire Team <info@ipfire.org>                      #
 #                                                                             #
 # This program is free software: you can redistribute it and/or modify        #
 # it under the terms of the GNU General Public License as published by        #
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX=ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX=ipfire-xen
-else
-       VERSUFIX=ipfire
-endif
-endif
+VERSUFIX=ipfire$(KCFG)
 
 VER        = 2.2.1
 TVER       = 2.2.1
index 93a01a2b578c6b2902cdfef25af77614012207ed..8fe88cdd16a3ef3a26a57dbeffbdf618778d9681 100644 (file)
--- a/lfs/e1000
+++ b/lfs/e1000
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX = ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX = ipfire-xen
-else
-       VERSUFIX = ipfire
-endif
-endif
+VERSUFIX = ipfire$(KCFG)
 
 VER        = 8.0.30
 
index 274676131f69559820e72e7ec559d98ea1fd0c5f..70ca9c62f37154b12f5429c03605296a81dc7874 100644 (file)
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX = ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX = ipfire-xen
-else
-       VERSUFIX = ipfire
-endif
-endif
+VERSUFIX = ipfire$(KCFG)
 
 VER        = 1.3.10a
 
diff --git a/lfs/igb b/lfs/igb
index 90d3d616ee893905aea5b89d4eb25e346e53fa19..00996b44e0f70283a21bba144ba45b958a2423d9 100644 (file)
--- a/lfs/igb
+++ b/lfs/igb
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX = ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX = ipfire-xen
-else
-       VERSUFIX = ipfire
-endif
-endif
+VERSUFIX   = ipfire$(KCFG)
 
 VER        = 3.0.19
 
index ebb148fa33e9d630094178d466c64545e23e52f8..6e5ecfaefd3ec63c0e83e79ee434cea5239e3eed 100644 (file)
--- a/lfs/kqemu
+++ b/lfs/kqemu
@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # IPFire.org - A linux based firewall                                         #
-# Copyright (C) 2010  IPFire Team <info@ipfire.org>                           #
+# Copyright (C) 2007-2011  IPFire Team <info@ipfire.org>                      #
 #                                                                             #
 # This program is free software: you can redistribute it and/or modify        #
 # it under the terms of the GNU General Public License as published by        #
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX=ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX=ipfire-xen
-else
-       VERSUFIX=ipfire
-endif
-endif
+VERSUFIX=ipfire$(KCFG)
 
 VER        = 1.4.0pre1
 
index fad1c59ad9466867a0460757b8f0890d7ced4a8e..0280b5e69a43afc986886be355e93d0002134d15 100644 (file)
@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # IPFire.org - A linux based firewall                                         #
-# Copyright (C) 2010  IPFire Team <info@ipfire.org>                           #
+# Copyright (C) 2007-2011  IPFire Team <info@ipfire.org>                      #
 #                                                                             #
 # This program is free software: you can redistribute it and/or modify        #
 # it under the terms of the GNU General Public License as published by        #
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX=ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX=ipfire-xen
-else
-       VERSUFIX=ipfire
-endif
-endif
+VERSUFIX=ipfire$(KCFG)
 
 VER        = 3.0b
 
index 25ff5daf406871869aff2f7516118832d8c06361..fe2cf2a60d0da415f659933389579c1d5dfc7514 100644 (file)
--- a/lfs/linux
+++ b/lfs/linux
@@ -40,15 +40,7 @@ DEPS    = ""
 # Normal build or XEN build.
 #
 
-ifeq "$(PAE)" "1"
-       VERSUFIX=ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX=ipfire-xen
-else
-       VERSUFIX=ipfire
-endif
-endif
+VERSUFIX=ipfire$(KCFG)
 
 ifeq "$(HEADERS)" "1"
 ifeq "$(TOOLS)" "1"
@@ -122,7 +114,7 @@ $(TARGET) : $(patsubst %,$(DIR_DL)/%,$(objects))
 
        ln -svf linux-$(VER) $(DIR_SRC)/linux
 
-ifeq "$(XEN)" "1"
+ifeq "$(KCFG)" "-xen"
        # Apply gentoo Xen patches
        mkdir -p $(DIR_SRC)/xen-patches
        cd $(DIR_SRC)/xen-patches && tar jxf $(DIR_DL)/xen-patches-2.6.32-2f.tar.bz2
@@ -188,7 +180,7 @@ else
        cd $(DIR_APP) && make CC="$(KGCC)" clean
        cd $(DIR_APP) && sed -i -e 's/EXTRAVERSION\ =.*/EXTRAVERSION\ =\ $(PATCHLEVEL)-$(VERSUFIX)/' Makefile
 
-ifeq "$(XEN)" "1"
+ifeq "$(KCFG)" "-xen"
        cd $(DIR_APP) && make $(MAKETUNING) CC="$(KGCC)" vmlinuz
        cd $(DIR_APP) && cp -v arch/i386/boot/vmlinuz /boot/vmlinuz-$(VER)-$(VERSUFIX)
 else
@@ -209,8 +201,7 @@ endif
        cd $(DIR_APP) && make CC="$(KGCC)" $(MAKETUNING) modules_install
        cd $(DIR_APP) && make CC="$(KGCC)" $(MAKETUNING) firmware_install
 
-ifneq "$(PAE)" "1"
-ifneq "$(XEN)" "1"
+ifeq "$(KCFG)" ""
        # Only do this once on the standard kernel pass
        cd $(DIR_APP) && install -m 755 usr/gen_init_cpio /sbin/
 
@@ -235,7 +226,6 @@ ifneq "$(XEN)" "1"
        # Disable ipv6 at runtime
        echo "options ipv6 disable_ipv6=1" > /etc/modprobe.d/ipv6
 
-endif
 endif
 
        # Remove mISDN modules
index 7ea0c67a1bc5026c198c86ea0d8ea46f241d5ffd..9c5f4004a367751efd24da8107924553771b27c2 100644 (file)
--- a/lfs/mISDN
+++ b/lfs/mISDN
@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # IPFire.org - A linux based firewall                                         #
-# Copyright (C) 2010  IPFire Team  <info@ipfire.org>                          #
+# Copyright (C) 2007-2011  IPFire Team  <info@ipfire.org>                     #
 #                                                                             #
 # This program is free software: you can redistribute it and/or modify        #
 # it under the terms of the GNU General Public License as published by        #
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX=ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX=ipfire-xen
-else
-       VERSUFIX=ipfire
-endif
-endif
+VERSUFIX=ipfire$(KCFG)
 
 VER        = 20100525
 
index fb44be98ba9658df755342e6c308259b9389eadf..2d3f97ed99d1fd18674e69f33986cee19a5626f9 100644 (file)
@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # IPFire.org - A linux based firewall                                         #
-# Copyright (C) 2010  IPFire Team <info@ipfire.org>                           #
+# Copyright (C) 2007-2011  IPFire Team <info@ipfire.org>                      #
 #                                                                             #
 # This program is free software: you can redistribute it and/or modify        #
 # it under the terms of the GNU General Public License as published by        #
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX=ipfire-pae
-else
-
-ifeq "$(XEN)" "1"
-       VERSUFIX=ipfire-xen
-else
-       VERSUFIX=ipfire
-endif
-endif
+VERSUFIX=ipfire$(KCFG)
 
 VER        = hal-0.10.5.6-r4119-20100201
 
index a523c68dd0244f1a41dd1c363afbaa9387392a6f..266e891bd1139eb696c1f034ac735ea0bc55a2b3 100644 (file)
--- a/lfs/r8101
+++ b/lfs/r8101
@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # IPFire.org - A linux based firewall                                         #
-# Copyright (C) 2010  IPFire Team <info@ipfire.org>                           #
+# Copyright (C) 2007-2011  IPFire Team <info@ipfire.org>                      #
 #                                                                             #
 # This program is free software: you can redistribute it and/or modify        #
 # it under the terms of the GNU General Public License as published by        #
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX = ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX = ipfire-xen
-else
-       VERSUFIX = ipfire
-endif
-endif
+VERSUFIX = ipfire$(KCFG)
 
 VER        = 1.019.00
 
index a80d15694d4ab15b1e1e60329e83107d55324151..2a4e2abad2ca3ff3b98e7a19be3d394bef9b4880 100644 (file)
--- a/lfs/r8168
+++ b/lfs/r8168
@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # IPFire.org - A linux based firewall                                         #
-# Copyright (C) 2010  IPFire Team <info@ipfire.org>                           #
+# Copyright (C) 2007-2011  IPFire Team <info@ipfire.org>                      #
 #                                                                             #
 # This program is free software: you can redistribute it and/or modify        #
 # it under the terms of the GNU General Public License as published by        #
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX = ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX = ipfire-xen
-else
-       VERSUFIX = ipfire
-endif
-endif
+VERSUFIX = ipfire$(KCFG)
 
 VER        = 8.019.00
 
index b738385361f5e1b1ec1eb15407c8a66e3503b85e..85a6dc179da666eb98a34a824ac1bfaf2c75b923 100644 (file)
--- a/lfs/r8169
+++ b/lfs/r8169
@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # IPFire.org - A linux based firewall                                         #
-# Copyright (C) 2010  IPFire Team <info@ipfire.org>                           #
+# Copyright (C) 2007-2011  IPFire Team <info@ipfire.org>                      #
 #                                                                             #
 # This program is free software: you can redistribute it and/or modify        #
 # it under the terms of the GNU General Public License as published by        #
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX = ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX = ipfire-xen
-else
-       VERSUFIX = ipfire
-endif
-endif
+VERSUFIX = ipfire$(KCFG)
 
 VER        = 6.014.00
 
index 6c6a5fc5bba69ac63a04eb483110cfb1807a34e6..730173efd7b22c624c152a95b5561fa529fc8db1 100644 (file)
 
 include Config
 
-ifeq "$(PAE)" "1"
-       VERSUFIX=ipfire-pae
-else
-ifeq "$(XEN)" "1"
-       VERSUFIX=ipfire-xen
-else
-       VERSUFIX=ipfire
-endif
-endif
+VERSUFIX=ipfire$(KCFG)
 
 VER        = git20110427
 
diff --git a/make.sh b/make.sh
index 84597c2c429b7d732908dfde4cc6a9ce7467e882..c65ad5a22cdb429616fd375b18788d416eb9bd90 100755 (executable)
--- a/make.sh
+++ b/make.sh
@@ -368,59 +368,59 @@ buildipfire() {
 
   # The xen and PAE kernels are only available for x86
   if [ "${MACHINE_TYPE}" != "arm" ]; then
-    ipfiremake linux                   XEN=1
-    ipfiremake kqemu                   XEN=1
-    ipfiremake v4l-dvb                 XEN=1
-    ipfiremake madwifi                 XEN=1
-    ipfiremake mISDN                   XEN=1
-    ipfiremake dahdi                   XEN=1 KMOD=1
-    ipfiremake cryptodev                       XEN=1
-    ipfiremake compat-wireless         XEN=1
-    ipfiremake r8169                   XEN=1
-    ipfiremake r8168                   XEN=1
-    ipfiremake r8101                   XEN=1
-    ipfiremake e1000                   XEN=1
-    ipfiremake e1000e                  XEN=1
-    ipfiremake igb                     XEN=1
-    ipfiremake linux                   PAE=1
-    ipfiremake kqemu                   PAE=1
-    ipfiremake kvm-kmod                        PAE=1
-    ipfiremake v4l-dvb                 PAE=1
-    ipfiremake madwifi                 PAE=1
-    ipfiremake alsa                    PAE=1 KMOD=1
-    ipfiremake mISDN                   PAE=1
-    ipfiremake dahdi                   PAE=1 KMOD=1
-    ipfiremake cryptodev                       PAE=1
-    ipfiremake compat-wireless         PAE=1
-#    ipfiremake r8169                  PAE=1
-#    ipfiremake r8168                  PAE=1
-#    ipfiremake r8101                  PAE=1
-    ipfiremake e1000                   PAE=1
-    ipfiremake e1000e                  PAE=1
-    ipfiremake igb                     PAE=1
+    ipfiremake linux                   KCFG="-xen"
+    ipfiremake kqemu                   KCFG="-xen"
+    ipfiremake v4l-dvb                 KCFG="-xen"
+    ipfiremake madwifi                 KCFG="-xen"
+    ipfiremake mISDN                   KCFG="-xen"
+    ipfiremake dahdi                   KCFG="-xen" KMOD=1
+    ipfiremake cryptodev               KCFG="-xen"
+    ipfiremake compat-wireless         KCFG="-xen"
+    ipfiremake r8169                   KCFG="-xen"
+    ipfiremake r8168                   KCFG="-xen"
+    ipfiremake r8101                   KCFG="-xen"
+    ipfiremake e1000                   KCFG="-xen"
+    ipfiremake e1000e                  KCFG="-xen"
+    ipfiremake igb                     KCFG="-xen"
+    ipfiremake linux                   KCFG="-pae"
+    ipfiremake kqemu                   KCFG="-pae"
+    ipfiremake kvm-kmod                        KCFG="-pae"
+    ipfiremake v4l-dvb                 KCFG="-pae"
+    ipfiremake madwifi                 KCFG="-pae"
+    ipfiremake alsa                    KCFG="-pae" KMOD=1
+    ipfiremake mISDN                   KCFG="-pae"
+    ipfiremake dahdi                   KCFG="-pae" KMOD=1
+    ipfiremake cryptodev               KCFG="-pae"
+    ipfiremake compat-wireless         KCFG="-pae"
+#    ipfiremake r8169                  KCFG="-pae"
+#    ipfiremake r8168                  KCFG="-pae"
+#    ipfiremake r8101                  KCFG="-pae"
+    ipfiremake e1000                   KCFG="-pae"
+    ipfiremake e1000e                  KCFG="-pae"
+    ipfiremake igb                     KCFG="-pae"
   fi
 
   # Default kernel build
-  ipfiremake linux
-  ipfiremake v4l-dvb
-  ipfiremake kqemu
-  ipfiremake kvm-kmod
-  ipfiremake madwifi
+  ipfiremake linux                     KCFG=""
+  ipfiremake v4l-dvb                   KCFG=""
+  ipfiremake kqemu                     KCFG=""
+  ipfiremake kvm-kmod                  KCFG=""
+  ipfiremake madwifi                   KCFG=""
   if [ "${MACHINE_TYPE}" != "arm" ]; then
     #todo enable alsa driver in kernel config
-    ipfiremake alsa                    KMOD=1
+    ipfiremake alsa                    KCFG="" KMOD=1
   fi
   #undefined declaration in echo canceler try to fix later
-  ipfiremake mISDN
-  ipfiremake dahdi                     KMOD=1
-  ipfiremake cryptodev
-  ipfiremake compat-wireless
-#  ipfiremake r8169
-#  ipfiremake r8168
-#  ipfiremake r8101
-  ipfiremake e1000
-  ipfiremake e1000e
-  ipfiremake igb
+  ipfiremake mISDN                     KCFG=""
+  ipfiremake dahdi                     KCFG="" KMOD=1
+  ipfiremake cryptodev                 KCFG=""
+  ipfiremake compat-wireless           KCFG=""
+#  ipfiremake r8169                    KCFG=""
+#  ipfiremake r8168                    KCFG=""
+#  ipfiremake r8101                    KCFG=""
+  ipfiremake e1000                     KCFG=""
+  ipfiremake e1000e                    KCFG=""
+  ipfiremake igb                       KCFG=""
   ipfiremake pkg-config
   ipfiremake linux-atm
   ipfiremake cpio